@@ -31,6 +31,7 @@ from collections import defaultdict
 
 import dxpy
 from .printing import (RED, GREEN, BLUE, YELLOW, WHITE, BOLD, UNDERLINE, ENDC, DELIMITER, get_delimiter, fill)
+from .pretty_print import format_timedelta
 from ..compat import basestring, USING_PYTHON2
 
 def JOB_STATES(state):
@@ -778,7 +779,8 @@ def print_execution_desc(desc):
                          'name', 'instanceType', 'systemRequirements', 'executableName', 'failureFrom', 'billTo',
                          'startedRunning', 'stoppedRunning', 'stateTransitions',
                          'delayWorkspaceDestruction', 'stages', 'totalPrice', 'isFree', 'invoiceMetadata',
-                         'priority', 'sshHostKey', 'internetUsageIPs']
+                         'priority', 'sshHostKey', 'internetUsageIPs', 'spotWaitTime', 'maxTreeSpotWaitTime',
+                         'maxJobSpotWaitTime']
 
     print_field("ID", desc["id"])
     print_field("Class", desc["class"])
@@ -914,6 +916,12 @@ def print_execution_desc(desc):
                     print_nofill_field(" sys reqs", YELLOW() + json.dumps(cloned_sys_reqs) + ENDC())
     if not desc.get('isFree') and desc.get('totalPrice') is not None:
         print_field('Total Price', format_currency(desc['totalPrice'], meta=desc['currency']))
+    if desc.get('spotWaitTime') is not None:
+        print_field('Spot Wait Time', format_timedelta(desc.get('spotWaitTime'), in_seconds=True))
+    if desc.get('maxTreeSpotWaitTime') is not None:
+        print_field('Max Tree Spot Wait Time', format_timedelta(desc.get('maxTreeSpotWaitTime'), in_seconds=True))
+    if desc.get('maxJobSpotWaitTime') is not None:
+        print_field('Max Job Spot Wait Time', format_timedelta(desc.get('maxJobSpotWaitTime'), in_seconds=True))
     if desc.get('invoiceMetadata'):
         print_json_field("Invoice Metadata", desc['invoiceMetadata'])
     if desc.get('sshHostKey'):
